pub fn sha256_crypt(password: &[u8], salt: &[u8], params: Params) -> [u8; 32]Expand description
The SHA-256-crypt function which outputs a uniformly random byte array.
Arguments
-
password: the password to process as a byte vector -
salt: the salt value to use as a byte vector -
params: the parameters to useWARNING: Make sure to compare this value in constant time!